# Change Log
This project adheres to [Semantic Versioning](http://semver.org/).

## 2.0
* Remove Node.js 9 and Node.js 4 support (by Aleks Hudochenkov).
* Remove IE and “dead” browsers from Babel.
* Use PostCSS 7.0 (by Aleks Hudochenkov).

## 1.0.1
* Fix nested inline comments parsing.

## 1.0
* Use PostCSS 6.0.
* Use `babel-preset-env`.

## 0.2
* Show error on semicolons and curly brackets.
* Fix source map mappings.

## 0.1.6
* Fix empty comments parsing.

## 0.1.5
* Put comments after declaration semicolon.
* Use PostCSS 5.1.

## 0.1.4
* Fix parsing nested properties.

## 0.1.3
* Fix source map generation.

## 0.1.2
* Fix rule/declaration selection in nested rules.

## 0.1.1
* Fix comment between declaration case.
* Add logo (by Maria Keller).

## 0.1
* Add selector pseudo-classes support.

## 0.0.1
* Initial release.
